package cn.iocoder.yudao.module.asset.controller.admin.assetinfo;

import cn.iocoder.yudao.framework.apilog.core.annotation.ApiAccessLog;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;
import cn.iocoder.yudao.module.asset.controller.admin.assetinfo.vo.AssetInfoPageReqVO;
import cn.iocoder.yudao.module.asset.controller.admin.assetinfo.vo.AssetInfoRespVO;
import cn.iocoder.yudao.module.asset.controller.admin.assetinfo.vo.AssetInfoSaveReqVO;
import cn.iocoder.yudao.module.asset.dal.dataobject.assetinfo.AssetInfoDO;
import cn.iocoder.yudao.module.asset.service.assetinfo.AssetInfoService;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.List;

import static cn.iocoder.yudao.framework.apilog.core.enums.OperateTypeEnum.EXPORT;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Tag(name = "管理后台 - 固定资产信息")
@RestController
@RequestMapping("/asset/info")
@Validated
public class AssetInfoController {

    @Resource
    private AssetInfoService infoService;

    @PostMapping("/create")
    @Operation(summary = "创建固定资产信息")
    @ApiOperationSupport(order = 1)
    // @PreAuthorize("@ss.hasPermission('asset:info:create')")
    public CommonResult<Long> createInfo(@Valid @RequestBody AssetInfoSaveReqVO createReqVO) {
        return success(infoService.createInfo(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新固定资产信息")
    @ApiOperationSupport(order = 2)
    // @PreAuthorize("@ss.hasPermission('asset:info:update')")
    public CommonResult<Boolean> updateInfo(@Valid @RequestBody AssetInfoSaveReqVO updateReqVO) {
        infoService.updateInfo(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除固定资产信息")
    @ApiOperationSupport(order = 3)
    @Parameter(name = "id", description = "编号", required = true)
    // @PreAuthorize("@ss.hasPermission('asset:info:delete')")
    public CommonResult<Boolean> deleteInfo(@RequestParam("id") Long id) {
        infoService.deleteInfo(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得固定资产信息")
    @ApiOperationSupport(order = 4)
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    // @PreAuthorize("@ss.hasPermission('asset:info:query')")
    public CommonResult<AssetInfoRespVO> getInfo(@RequestParam("id") Long id) {
        AssetInfoDO info = infoService.getInfo(id);
        return success(BeanUtils.toBean(info, AssetInfoRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得固定资产信息分页")
    @ApiOperationSupport(order = 5)
    // @PreAuthorize("@ss.hasPermission('asset:info:query')")
    public CommonResult<PageResult<AssetInfoRespVO>> getInfoPage(@Valid AssetInfoPageReqVO pageReqVO) {
        PageResult<AssetInfoDO> pageResult = infoService.getInfoPage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, AssetInfoRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出固定资产信息 Excel")
    @ApiOperationSupport(order = 6)
    // @PreAuthorize("@ss.hasPermission('asset:info:export')")
    @ApiAccessLog(operateType = EXPORT)
    public void exportInfoExcel(@Valid AssetInfoPageReqVO pageReqVO,
              HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<AssetInfoDO> list = infoService.getInfoPage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "固定资产信息.xls", "数据", AssetInfoRespVO.class,
                        BeanUtils.toBean(list, AssetInfoRespVO.class));
    }

}