package cn.iocoder.yudao.module.asset.controller.admin.assetreceiveinfo;

import cn.iocoder.yudao.framework.apilog.core.annotation.ApiAccessLog;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;
import cn.iocoder.yudao.module.asset.controller.admin.assetreceiveinfo.vo.AssetReceiveInfoPageReqVO;
import cn.iocoder.yudao.module.asset.controller.admin.assetreceiveinfo.vo.AssetReceiveInfoRespVO;
import cn.iocoder.yudao.module.asset.controller.admin.assetreceiveinfo.vo.AssetReceiveInfoSaveReqVO;
import cn.iocoder.yudao.module.asset.dal.dataobject.assetreceiveinfo.AssetReceiveInfoDO;
import cn.iocoder.yudao.module.asset.service.assetreceiveinfo.AssetReceiveInfoService;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.List;

import static cn.iocoder.yudao.framework.apilog.core.enums.OperateTypeEnum.EXPORT;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Tag(name = "管理后台 - 固定资产领用信息")
@RestController
@RequestMapping("/asset/receive-info")
@Validated
public class AssetReceiveInfoController {

    @Resource
    private AssetReceiveInfoService receiveInfoService;

    @PostMapping("/create")
    @Operation(summary = "创建固定资产领用信息")
    @ApiOperationSupport(order = 1)
    // @PreAuthorize("@ss.hasPermission('asset:receive-info:create')")
    public CommonResult<Long> createReceiveInfo(@Valid @RequestBody AssetReceiveInfoSaveReqVO createReqVO) {
        return success(receiveInfoService.createReceiveInfo(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新固定资产领用信息")
    @ApiOperationSupport(order = 2)
    // @PreAuthorize("@ss.hasPermission('asset:receive-info:update')")
    public CommonResult<Boolean> updateReceiveInfo(@Valid @RequestBody AssetReceiveInfoSaveReqVO updateReqVO) {
        receiveInfoService.updateReceiveInfo(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除固定资产领用信息")
    @ApiOperationSupport(order = 3)
    @Parameter(name = "id", description = "编号", required = true)
    // @PreAuthorize("@ss.hasPermission('asset:receive-info:delete')")
    public CommonResult<Boolean> deleteReceiveInfo(@RequestParam("id") Long id) {
        receiveInfoService.deleteReceiveInfo(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得固定资产领用信息")
    @ApiOperationSupport(order = 4)
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    // @PreAuthorize("@ss.hasPermission('asset:receive-info:query')")
    public CommonResult<AssetReceiveInfoRespVO> getReceiveInfo(@RequestParam("id") Long id) {
        AssetReceiveInfoDO receiveInfo = receiveInfoService.getReceiveInfo(id);
        return success(BeanUtils.toBean(receiveInfo, AssetReceiveInfoRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得固定资产领用信息分页")
    @ApiOperationSupport(order = 5)
    // @PreAuthorize("@ss.hasPermission('asset:receive-info:query')")
    public CommonResult<PageResult<AssetReceiveInfoRespVO>> getReceiveInfoPage(@Valid AssetReceiveInfoPageReqVO pageReqVO) {
        PageResult<AssetReceiveInfoDO> pageResult = receiveInfoService.getReceiveInfoPage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, AssetReceiveInfoRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出固定资产领用信息 Excel")
    @ApiOperationSupport(order = 6)
    // @PreAuthorize("@ss.hasPermission('asset:receive-info:export')")
    @ApiAccessLog(operateType = EXPORT)
    public void exportReceiveInfoExcel(@Valid AssetReceiveInfoPageReqVO pageReqVO,
              HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<AssetReceiveInfoDO> list = receiveInfoService.getReceiveInfoPage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "固定资产领用信息.xls", "数据", AssetReceiveInfoRespVO.class,
                        BeanUtils.toBean(list, AssetReceiveInfoRespVO.class));
    }

}