package cn.iocoder.yudao.module.asset.service.assetinfo;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import cn.iocoder.yudao.module.asset.controller.admin.assetinfo.vo.*;
import cn.iocoder.yudao.module.asset.dal.dataobject.assetinfo.AssetInfoDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;

import cn.iocoder.yudao.module.asset.dal.mysql.assetinfo.AssetInfoMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.asset.enums.ErrorCodeConstants.*;

/**
 * 固定资产信息 Service 实现类
 *
 * @author dp
 */
@Service
@Validated
public class AssetInfoServiceImpl implements AssetInfoService {

    @Resource
    private AssetInfoMapper infoMapper;

    @Override
    public Long createInfo(AssetInfoSaveReqVO createReqVO) {
        // 插入
        AssetInfoDO info = BeanUtils.toBean(createReqVO, AssetInfoDO.class);
        infoMapper.insert(info);
        // 返回
        return info.getId();
    }

    @Override
    public void updateInfo(AssetInfoSaveReqVO updateReqVO) {
        // 校验存在
        validateInfoExists(updateReqVO.getId());
        // 更新
        AssetInfoDO updateObj = BeanUtils.toBean(updateReqVO, AssetInfoDO.class);
        infoMapper.updateById(updateObj);
    }

    @Override
    public void deleteInfo(Long id) {
        // 校验存在
        validateInfoExists(id);
        // 删除
        infoMapper.deleteById(id);
    }

    private void validateInfoExists(Long id) {
        if (infoMapper.selectById(id) == null) {
            throw exception(INFO_NOT_EXISTS);
        }
    }

    @Override
    public AssetInfoDO getInfo(Long id) {
        return infoMapper.selectById(id);
    }

    @Override
    public PageResult<AssetInfoDO> getInfoPage(AssetInfoPageReqVO pageReqVO) {
        return infoMapper.selectPage(pageReqVO);
    }

}