package cn.iocoder.yudao.module.asset.service.assetreceiveinfo;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import cn.iocoder.yudao.module.asset.controller.admin.assetreceiveinfo.vo.*;
import cn.iocoder.yudao.module.asset.dal.dataobject.assetreceiveinfo.AssetReceiveInfoDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;

import cn.iocoder.yudao.module.asset.dal.mysql.assetreceiveinfo.AssetReceiveInfoMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.asset.enums.ErrorCodeConstants.*;

/**
 * 固定资产领用信息 Service 实现类
 *
 * @author dp
 */
@Service
@Validated
public class AssetReceiveInfoServiceImpl implements AssetReceiveInfoService {

    @Resource
    private AssetReceiveInfoMapper receiveInfoMapper;

    @Override
    public Long createReceiveInfo(AssetReceiveInfoSaveReqVO createReqVO) {
        // 插入
        AssetReceiveInfoDO receiveInfo = BeanUtils.toBean(createReqVO, AssetReceiveInfoDO.class);
        receiveInfoMapper.insert(receiveInfo);
        // 返回
        return receiveInfo.getId();
    }

    @Override
    public void updateReceiveInfo(AssetReceiveInfoSaveReqVO updateReqVO) {
        // 校验存在
        validateReceiveInfoExists(updateReqVO.getId());
        // 更新
        AssetReceiveInfoDO updateObj = BeanUtils.toBean(updateReqVO, AssetReceiveInfoDO.class);
        receiveInfoMapper.updateById(updateObj);
    }

    @Override
    public void deleteReceiveInfo(Long id) {
        // 校验存在
        validateReceiveInfoExists(id);
        // 删除
        receiveInfoMapper.deleteById(id);
    }

    private void validateReceiveInfoExists(Long id) {
        if (receiveInfoMapper.selectById(id) == null) {
            throw exception(RECEIVE_INFO_NOT_EXISTS);
        }
    }

    @Override
    public AssetReceiveInfoDO getReceiveInfo(Long id) {
        return receiveInfoMapper.selectById(id);
    }

    @Override
    public PageResult<AssetReceiveInfoDO> getReceiveInfoPage(AssetReceiveInfoPageReqVO pageReqVO) {
        return receiveInfoMapper.selectPage(pageReqVO);
    }

}