package cn.iocoder.yudao.module.attendance.service.business;

import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import cn.iocoder.yudao.module.attendance.controller.admin.business.vo.*;
import cn.iocoder.yudao.module.attendance.dal.dataobject.business.AttendanceBusinessDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;

import cn.iocoder.yudao.module.attendance.dal.mysql.business.AttendanceBusinessMapper;

import javax.annotation.Resource;

import java.time.LocalDate;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.attendance.enums.ErrorCodeConstants.*;

/**
 * 出差信息 Service 实现类
 *
 * @author zhaopq
 */
@Service
@Validated
public class AttendanceBusinessServiceImpl implements AttendanceBusinessService {

    @Resource
    private AttendanceBusinessMapper businessMapper;

    @Override
    public Long createBusiness(AttendanceBusinessSaveReqVO createReqVO) {
        // 插入
        AttendanceBusinessDO business = BeanUtils.toBean(createReqVO, AttendanceBusinessDO.class);
        businessMapper.insert(business);
        // 返回
        return business.getId();
    }

    @Override
    public void updateBusiness(AttendanceBusinessSaveReqVO updateReqVO) {
        // 校验存在
        validateBusinessExists(updateReqVO.getId());
        // 更新
        AttendanceBusinessDO updateObj = BeanUtils.toBean(updateReqVO, AttendanceBusinessDO.class);
        businessMapper.updateById(updateObj);
    }

    @Override
    public void deleteBusiness(Long id) {
        // 校验存在
        validateBusinessExists(id);
        // 删除
        businessMapper.deleteById(id);
    }

    private void validateBusinessExists(Long id) {
        if (businessMapper.selectById(id) == null) {
            throw exception(ATTENDANCE_BUSINESS_NOT_EXISTS);
        }
    }

    @Override
    public AttendanceBusinessDO getBusiness(Long id) {
        return businessMapper.selectById(id);
    }

    @Override
    public PageResult<AttendanceBusinessDO> getBusinessPage(AttendanceBusinessPageReqVO pageReqVO) {
        return businessMapper.selectPage(pageReqVO);
    }

    @Override
    public AttendanceBusinessDO selectByDateAndEmployeeId(LocalDate date, Long employeeId) {
        return businessMapper.selectByDateAndEmployeeId(date, employeeId);
    }


}