package cn.iocoder.yudao.module.attendance.service.out;

import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import cn.iocoder.yudao.module.attendance.controller.admin.out.vo.*;
import cn.iocoder.yudao.module.attendance.dal.dataobject.out.AttendanceOutDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;

import cn.iocoder.yudao.module.attendance.dal.mysql.out.AttendanceOutMapper;

import javax.annotation.Resource;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.attendance.enums.ErrorCodeConstants.*;

/**
 * 公务外出信息 Service 实现类
 *
 * @author zhaopq
 */
@Service
@Validated
public class AttendanceOutServiceImpl implements AttendanceOutService {

    @Resource
    private AttendanceOutMapper outMapper;

    @Override
    public Long createOut(AttendanceOutSaveReqVO createReqVO) {
        // 插入
        AttendanceOutDO out = BeanUtils.toBean(createReqVO, AttendanceOutDO.class);
        outMapper.insert(out);
        // 返回
        return out.getId();
    }

    @Override
    public void updateOut(AttendanceOutSaveReqVO updateReqVO) {
        // 校验存在
        validateOutExists(updateReqVO.getId());
        // 更新
        AttendanceOutDO updateObj = BeanUtils.toBean(updateReqVO, AttendanceOutDO.class);
        outMapper.updateById(updateObj);
    }

    @Override
    public void deleteOut(Long id) {
        // 校验存在
        validateOutExists(id);
        // 删除
        outMapper.deleteById(id);
    }

    private void validateOutExists(Long id) {
        if (outMapper.selectById(id) == null) {
            throw exception(ATTENDANCE_OUT_NOT_EXISTS);
        }
    }

    @Override
    public AttendanceOutDO getOut(Long id) {
        return outMapper.selectById(id);
    }

    @Override
    public PageResult<AttendanceOutDO> getOutPage(AttendanceOutPageReqVO pageReqVO) {
        return outMapper.selectPage(pageReqVO);
    }

}